g: A function to calculate G in the Pocock Design and return a...

Description Usage Arguments

View source: R/CARfunctions.R

Description

This function is not generally used. It is used in the calculation of the treatment assignments in psd

Usage

1
g(delts, p1 = 3/4, n.trt)

Arguments

delts

x is the vector of deltas in Pocock's design

p1

= 3/4


Gtmille2/seamlessTrial documentation built on Nov. 18, 2019, 5:16 a.m.