get.z.v.t: get.z.v.t function

Description Usage Arguments

View source: R/get.z.v.t.R

Description

gets z and v for all treatments at first look and for selected treatment at second look selection is prespecified or is of best treatment from first look if selected = 0

Usage

1
get.z.v.t(data, selected, n1, N1, N)

Arguments

data

data set with primary and secondary endpoint, and treatment

selected

The selected treatment from the first look

n1

Number of patients with primary endpoint available at first analysis

N1

Number of patients with secondary endpoint available at first analysis

N

The total number of patients in the trial


Gtmille2/seamlessTrial documentation built on Nov. 18, 2019, 5:16 a.m.