gets z and v for all treatments at first look and for selected treatment at second look selection is prespecified or is of best treatment from first look if selected = 0
1 |
data |
data set with primary and secondary endpoint, and treatment |
selected |
The selected treatment from the first look |
n1 |
Number of patients with primary endpoint available at first analysis |
N1 |
Number of patients with secondary endpoint available at first analysis |
N |
The total number of patients in the trial |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.